#
# spec file for package ncmpc
#
# Copyright (c) 2018 Packman team: http://packman.links2linux.org/
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/


Name:           ncmpc
Version:        0.36
Release:        2.1
Summary:        Curses Client for the Music Player Daemon
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Players
URL:            http://mpd.wikia.com/wiki/Client:Ncmpc
Source:         https://www.musicpd.org/download/ncmpc/0/ncmpc-%{version}.tar.xz
Patch3:         ncmpc-fix_meson_docdir.patch
BuildRequires:  gcc-c++
BuildRequires:  libboost_iostreams-devel >= 1.62
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0) >= 2.30
BuildRequires:  pkgconfig(libmpdclient) >= 2.9
BuildRequires:  python3-Sphinx
BuildRequires:  meson >= 0.47
BuildRequires:  ninja

%description
ncmpc is a curses client for the Music Player Daemon (MPD). ncmpc connects to
a MPD running on a machine on the local network, and controls this with an
interface inspired by cplay.

%lang_package
%prep
%autosetup -p1

%build
%meson \
       -Dlirc=disabled \
       -Dhtml_manual=false
%meson_build

%install
%meson_install

%find_lang %{name}

%files lang -f %{name}.lang

%files
%license COPYING
%doc AUTHORS NEWS README.rst
%doc doc/*.sample
%{_bindir}/ncmpc
%{_mandir}/man*/*

%changelog
* Mon Jan 13 2020 olaf@aepfle.de
- Update to version 0.36
* Thu Oct 11 2018 aloisio@gmx.com
- Update to version 0.32
  * fix crash bug on queue page
  * fix crash bug on lyrics page
  * fix off-by-one buffer overflow bug
  * fix manpage installation directory
  * fix build breakages with some ncurses builds
  * work around GCC 4.9 build failure
  * remove doxygen support
  * new dependency: Boost
  * remove dependency on GLib
  version 0.31
  * fix "No such song" in search screen
  * fix progressbar when colors are disabled
  * enable colors by default
  * allow configuring per-style background colors
  * keep current song in xterm title when MPD is paused
  * load configuration from $XDG_CONFIG_HOME/ncmpc/config
  * always show the screen list at the top
  * fix memory leak
  * require MPD 0.19
- Refreshed ncmpc-fix_meson_docdir.patch
- Dropped ncmpc-fix_meson_gcc_config.patch and ncmpc-c++11.patch
- Spec cleanup
* Sun Apr 15 2018 pascal.bleser@opensuse.org
- change build to use meson+ninja+sphinx
- ncmpc 0.30 - (2018-04-04)
  * fix crash after pressing ^W in search screen
  * fix crash bug in chat screen
  * fix completion list
  * new color "progressbar-background"
- ncmpc 0.29 - (2017-11-05)
  * fix crash after losing MPD connection
  * fix crash after DNS lookup error
- ncmpc 0.28 - (2017-09-21)
  * fix memory leak
  * hide the MPD password from the queue screen title
  * implement password for asynchronous connect
* Mon Apr 17 2017 olaf@aepfle.de
- ncmpc 0.27 - (2017-03-25)
  * work around connect failure if /var/run/mpd/socket does not exist
  * remove the status bar clock (option "display-time")
  * fix assertion failure after connect failure
  * several Windows build fixes
- ncmpc 0.26 - (2017-03-20)
  * require libmpdclient 2.9
  * adapt to lirc 0.9.4
  * lyricswiki: update regex
  * screen_song: show "f" and "dsd" formats
  * connect asynchronously
  * fix flickering in color mode
  * fix gcc 7 warnings
- ncmpc 0.25 - (2016-08-18)
  * implement "%%disc%%"
  * lyricswiki: handle redirects
  * lyricswiki: update XML format
* Tue Aug 26 2014 pascal.bleser@opensuse.org
- enable chat screen feature from 0.21
- update to 0.24:
  * fix crash on "jump" (hotkey ".")
  * save keys to path specified by --key-file
- changes from 0.22:
  * rename "playlist" to "queue"
  * remove useless "Connected to ..." message
  * require libmpdclient 2.3, MPD 0.16
  * patched color line-flags
  * configuration option "search-format"
  * remove broken leoslyrics plugin
  * show audio format in song screen
* Mon Feb 10 2014 pascal.bleser@opensuse.org
- update to 0.21:
  * add a chat screen for communication with other clients on the same server
  * song format: evaluate literal strings as true
  * fix crash on search screen when disconnected
  * screen_queue: fix crash on CMD_SCREEN_SWAP when the queue is empty
  * lyricswiki: fix Ruby 2.0 and UTF-8
* Mon Feb  6 2012 pascal.bleser@opensuse.org
- update to 0.20:
  * increase connection timeout to 5 seconds
  * screen_queue: follow songs when they are moved out of the visible range
  * screen_lyrics: You can now edit lyrics by pressing 'e'
  * configurable timeout for MPD connections
  * screen_keydef: show command descriptions
  * show the paths of the configuration files in --version output
* Fri Aug  5 2011 detlef@links2linux.de
- new upstream version <0.18>
  * require libmpdclient 2.2
  * show real server address in status message
  * fix crash after "clear" command
  * po: added Polish translation
* Sat Sep 25 2010 detlef@links2linux.de
- new upstream version <0.18>
  * screen_song: show song range
  * screen_artist: respect artist when adding albums
  * po: added Italian translation
* Sat Jul 17 2010 detlef@links2linux.de
- new upstream version <0.17>
  * screen_queue: fix range selection check on "shuffle"
  * screen_browser: check for error before adding song to playlist
  * po: added Brazilian Portuguese translation
* Mon Jan 18 2010 detlef@links2linux.de
- new upstream version <0.16.1>
  * screen_queue: always update the list size
  * screen_browser: fixed jump to playlist file
* Wed Dec 30 2009 detlef@links2linux.de
- new upstream version <0.16>
* Thu Jul 23 2009 detlef@links2linux.de
- new upstream version <0.14>
* Sun Jan 11 2009 detlef@links2linux.de
- new upstream version <0.13>
* Sat Dec  6 2008 detlef@links2linux.de
- new upstream version <0.12>
* Fri Oct 20 2006 detlef@links2linux.de
- fix install configfiles
* Mon Aug 28 2006 detlef@links2linux.de
- fix docdir
- add default-configs in /etc
* Fri Jul 28 2006 detlef@links2linux.de
- first PackMan-Build
